/*
 * User Mode Sandbox for Grid
 * Copyright (C) 2004 Tangui Morlier
 * Copyright (C) 2004 Grand-Large (INRIA Futurs)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
#ifndef FILE_FUNCTIONS_H
#define FILE_FUNCTIONS_H
#include <fcntl.h> 
#include "common.h"
#include "sandboxRules.h" 

/**
 * Filter for files operations
 *
 * return 0 if the r/w/x operation is done in a non listed bellow dirrectory
 */
int file_filter(struct ptrace_info_struct * pi, char* ptr, char* msg);

int execve_filter(struct ptrace_info_struct * pi, char* ptr, char* msg);


/**
 * Rewrite the access returns depending on the rules defined bellow
 */
int access_rewriter(struct ptrace_info_struct * pi, char* ptr, char* msg);

/**
 * Rewrite the openfile returns depending on the rules defined bellow
 */
int file_rewriter(struct ptrace_info_struct * pi, char* ptr, char* msg);

/**
 * Rewrite the open in read file returns depending on the rules defined bellow
 *  AND
 * Filter the open in write
 */
int file_rewriter_filter(struct ptrace_info_struct * pi, char* ptr, char* msg);

/**
 * Log files operation
 */
int file_logger(struct ptrace_info_struct * pi, char* ptr, char* msg);
int execve_logger(struct ptrace_info_struct * pi, char* ptr, char* msg);

/**
 * This decoder is used for link like operation 
 *  (the first param correspond on write op, the second one on a read)
 */
void link_file_decoder(struct ptrace_info_struct * pi, void * decoded);

/**
 * Decode a read operation (i.e. chmod)
 */
void r_file_decoder(struct ptrace_info_struct * pi, void * decoded);
/**
 * Decode a execution (i.e. execve)
 */
void execve_decoder(struct ptrace_info_struct * pi, void * decoded);
/**
 * Decode a read or/and write operation (typically an open)
 */
void rw_file_decoder(struct ptrace_info_struct * pi, void * decoded);
#endif // FILE_FUNCTIONS_H









