/*
 * User Mode Sandbox for Grid
 * Copyright (C) 2004 Tangui Morlier
 * Copyright (C) 2004 Grand-Large (INRIA Futurs)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
#ifndef PTRACE_DECODE_H
#define PTRACE_DECODE_H
#include <linux/ptrace.h>
#include <sys/types.h>
#include "common.h"

/** decodeString() :
 *      Read a string on user memory
 *
 * return:
 *      The size of the decoded string or -1 on error
 *
 * params:
 *      pid:  the pid of the sandboxed process which has called this syscall
 *      addr: user space memory adresse where to read the string
 *      str: a pointer where the string will be copied (OUT)
 *      max_len: the size max of the string
 */
long decodeString(pid_t pid, long addr, char* str, int max_len);


/** decodeWord():
 *      Read a word on user memory
 * return:
 *      -1 on error
 * 
 * params:
 *      pid:  the pid of the sandboxed process which has called this syscall
 *      addr: user space memory adresse where to read the word
 */
long decodeWord(pid_t pid, long addr);


/** decodeStruct() :
 *      Read a struct on user memory
 *
 * return:
 *      The size of the decoded struct or -1 on error
 *
 * params:
 *      pid:  the pid of the sandboxed process which has called this syscall
 *      addr: user space memory adresse where to read the struct
 *      struct_ptr:  a pointer where the struct will be copied (OUT)
 *      size_struct: the size of the struct
 */
long decodeStruct(pid_t pid, long addr, void * struct_ptr, int size_struct);

#endif //PTRACE_DECODE_H
